@@ -2,6 +2,12 @@ from .spacy_lang import SpacyLanguage
 from .sense2vec_lang import Sense2VecLanguage
 from .fasttext_lang import FasttextLanguage
 from .countvector_lang import CountVectorLanguage
-from .bpemblang import BPEmbLang
+from .bpemblang import BytePairLang
 
-__all__ = ["SpacyLanguage", "Sense2VecLanguage", "FasttextLanguage", "CountVectorLanguage", "BPEmbLang"]
+__all__ = [
+    "SpacyLanguage",
+    "Sense2VecLanguage",
+    "FasttextLanguage",
+    "CountVectorLanguage",
+    "BytePairLang",
+]
